summaryrefslogtreecommitdiffstats
path: root/qmake/generators/win32/msvc_dsp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qmake/generators/win32/msvc_dsp.cpp')
-rw-r--r--qmake/generators/win32/msvc_dsp.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/qmake/generators/win32/msvc_dsp.cpp b/qmake/generators/win32/msvc_dsp.cpp
index 988d4632..568ff616 100644
--- a/qmake/generators/win32/msvc_dsp.cpp
+++ b/qmake/generators/win32/msvc_dsp.cpp
@@ -365,7 +365,7 @@ DspMakefileGenerator::writeDspParts(TQTextStream &t)
list.sort();
TQStringList::Iterator it;
// dump the image list to a file UIC can read.
TQFile f( "images.tmp" );
f.open( IO_WriteOnly );
TQTextStream ts( &f );
@@ -464,7 +464,7 @@ DspMakefileGenerator::writeDspParts(TQTextStream &t)
t << "USERDEP_" << base << "=\"$(TQTDIR)\\bin\\tqmoc.exe\" \"$(TQTDIR)\\bin\\tquic.exe\"" << endl << endl;
- TQString build = "\n\n# Begin Custom Build - Uic'ing " + base + "...\n"
+ TQString build = "\n\n# Begin Custom Build - TQUic'ing " + base + "...\n"
"InputPath=.\\" + base + "\n\n" "BuildCmds= \\\n\t" + uicpath + base +
" -o " + uiHeadersDir + fname + ".h \\\n" "\t" + uicpath + base +
" -i " + fname + ".h -o " + uiSourcesDir + fname + ".cpp \\\n"
@@ -365,7 +365,7 @@ DspMakefileGenerator::writeDspParts(TQTextStream &t)
list.sort();
TQStringList::Iterator it;
- // dump the image list to a file UIC can read.
+ // dump the image list to a file TQUIC can read.
TQFile f( "images.tmp" );
f.open( IO_WriteOnly );